.. kwarray documentation master file, created by
   sphinx-quickstart on Sat Feb 16 21:11:42 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


:gitlab_url: https://gitlab.kitware.com/computer-vision/kwarray


.. The large version wont work because github strips rst image rescaling. https://i.imgur.com/AcWVroL.png
    # TODO: Add a logo
    .. image:: https://i.imgur.com/PoYIsWE.png
       :height: 100px
       :align: left

Welcome to kwarray's documentation!
===================================


.. The __init__ files contains the top-level documentation overview
.. autoapimodule:: kwarray
    :show-inheritance:
    :special-members: __init__


Function Usefulness
===================

================================================================ ================
 Function name                                                   Usefulness
================================================================ ================
:func:`kwarray.ArrayAPI`                                                      219
:func:`kwarray.ensure_rng`                                                    135
:func:`kwarray.boolmask`                                                       23
:func:`kwarray.stats_dict`                                                     21
:func:`kwarray.DataFrameArray`                                                 21
:func:`kwarray.group_indices`                                                  20
:func:`kwarray.shuffle`                                                        20
:func:`kwarray.argmaxima`                                                      16
:func:`kwarray.seed_global`                                                     8
:func:`kwarray.maxvalue_assignment`                                             7
:func:`kwarray.one_hot_embedding`                                               7
:func:`kwarray.atleast_nd`                                                      6
:func:`kwarray.iter_reduce_ufunc`                                               5
:func:`kwarray.isect_flags`                                                     5
:func:`kwarray.group_items`                                                     4
:func:`kwarray.mincost_assignment`                                              3
:func:`kwarray.standard_normal`                                                 3
:func:`kwarray.arglexmax`                                                       2
:func:`kwarray.apply_grouping`                                                  1
:func:`kwarray.DataFrameLight`                                                  1
:func:`kwarray.uniform`                                                         1
================================================================ ================


.. toctree::

   kwarray




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
